@@ -30,6 +30,13 @@ except:
 
 """
 main module of ansiblator - wrapper around ansible
+
+TODO:
+improve fabric like api for more improvments
+make more tests
+try to improve dynamic inventory
+improve logging
+
 """
 try:
     from ansiblator.version import __version__
@@ -37,10 +44,10 @@ except ImportError:
     __version__ = 0
 
 __version__ = "0.5-{}".format(__version__)
-__author__ = "Zdenek Dlauhy, Michal Dlauhy"
+__author__ = "pripravto-service"
 __email__ = "test@dlauhy.cz"
 __url__ = "http://www.pripravto.cz"
-__desc__ = "Ansiblator - make ansible api more pythonic and usefull"
+__desc__ = "Ansiblator - makes Ansible api more pythonic and usefull inside python itself"
 __sys_name__ = "ansiblator"
 __license__ = "MIT"
 
@@ -49,7 +56,7 @@ __license__ = "MIT"
 class DictToInventory(object):
     """
 
-    dict to inventory file mapper
+    dict to inventory file mapper::
 
         import ansiblator.api as an
         dict_data = {'pc':[{'ssh_host':'192.168.0.10', 'ssh_user':'test_user', 'su_user':'root'},
@@ -61,6 +68,12 @@ class DictToInventory(object):
 
     """
     def __init__(self, dict_data, filename="/tmp/out"):
+        """
+        :param dict_data: dict which would be converted to inventory
+        :type dict_data: dict
+        :param filename: filanema
+        :type filename: str
+        """
         self.data = []
         self.filename = filename
         self.dict_to_inverntory(dict_data)
@@ -108,7 +121,7 @@ class Ansiblator(object):
     ansible without playbooks, so more like fabric.
 
     Ansible is then more powerfull and it will allow to chain commands with
-    python commands.
+    python commands. Ansible documentation is on http://docs.ansible.com/
 
     Get started
     ===========
@@ -140,9 +153,10 @@ class Ansiblator(object):
         ans.run_all()
         ans.copy(src="/tmp/aabc.csv", dest="/tmp/",pattern="pc",now=True)
 
-    use dictionary::
+    use dictionary to create ::
 
-        inv = {'pc':[{'ssh_host':'192.168.0.10', 'ssh_user':'test_user', 'su_user':'root'}}
+        inv = {'pc':[{'ssh_host':'192.168.0.10', 'ssh_user':'test_user', 'su_user':'root'},
+                    {'ssh_host':'192.168.0.12', 'ssh_user':'test_user2', 'su_pass':'paasswd','su_user':'root'}]}
         ans = Ansiblator(inventory=inv)
         ans.run("uname -a", now=True)
 
@@ -155,18 +169,18 @@ class Ansiblator(object):
 
     testing::
 
-        return_code = ans.run("uname -a", now=True, use_shell=True)
+        return_code = ans.local("uname -a", now=True, use_shell=True)
         return_code['contacted']
 
         or
 
-        return_code = ans.run(["uname", "-a"], now=True, use_shell=False)
+        return_code = ans.local(["uname", "-a"], now=True, use_shell=False)
         return_code['contacted']
 
     Info
     ====
     For more information consult functions or ansible documentation.
-    more information can be also used on www.pripravto.cz. You can also
+    more information can be also used on http://www.pripravto.cz. You can also
     contact us there.
 
 
@@ -207,16 +221,17 @@ class Ansiblator(object):
         self.host = host
         self.stop_on_error = stop_on_error
         self.use_shell = use_shell
-        # parse inventory (str, dict, etc)
-        inventory = self.parse_inventory(inventory)
-        self.inventory = ansible.inventory.Inventory(inventory)
-
+        self.inventory = self.parse_inventory(inventory)
         log.debug("Intializing ansible: {}".format(self))
 
     def get_host_var(self, host):
         return self.inventory.get_variables(host)
 
     def parse_inventory(self, inventory):
+        """
+        :param inventory: some inventory specification
+        :type inventory: dict or str
+        """
         home = os.environ.get('HOME', '/tmp/')
         if isinstance(inventory, str):
             if not inventory.startswith("/"):
@@ -227,6 +242,10 @@ class Ansiblator(object):
             inventory = filename
         else:
             pass
+        if isinstance(inventory, ansible.inventory.Inventory):
+            pass
+        else:
+            inventory = ansible.inventory.Inventory(inventory)
         return inventory
 
 
@@ -272,6 +291,7 @@ class Ansiblator(object):
     def runner_ans(self, cmd="uptime", pattern=None, module_name=None, inventory=None,
                    now=None, su=None, sudo=None, su_user=None, su_pass=None,
                    sudo_pass=None, host=None, **kwargs):
+        """main ansible wrapper"""
         if module_name is None:
             module_name = self.module_name
         if pattern is None:
@@ -279,7 +299,7 @@ class Ansiblator(object):
         if inventory is None:
             inventory = self.inventory
         else:
-            inventory = ansible.inventory.Inventory(inventory)
+            inventory = self.parse_inventory(inventory)
         if now is None:
             now = self.run_at_once
         if sudo is None:
@@ -332,6 +352,9 @@ class Ansiblator(object):
         :type runner: dict or obj
         :param now: run now?
         :type now: bool
+        :param use_shell: use shell when subbprocess is running
+        :type use_shell: bool
+
 
         function to run or append runner
         """
@@ -374,7 +397,7 @@ class Ansiblator(object):
         :type cmd: str
         :param use_ansible: do you want to use ansible or local subprocess?
         :type use_ansible: bool
-        :param module_name: name of ansible module
+        :param module_name: Zdenek Dlauhy, Michal Dlauhyname of ansible module
         :type module_name: str
         :param inventory: inventory object
         :type inventory: <inventory>
